
# QM-QUA SDK

QUA is a pulse-level language used to control a Quantum System.
Read more about it and it's uses here: https://arxiv.org/abs/2303.03816

This package, QM-QUA, is an implementation that uses the Quantum Machines QOP controller and is used both to 
communicate with the QOP and to implement a Pythonic implementation (DSL) of QUA. 
 
To learn how to use this package, please visit the documentation website at: https://qm-docs.qualang.io/

